@@ -2,7 +2,8 @@
     use strict;
     use warnings;
     use base 'Catalyst::Action';
-    use Class::C3;
+    use MRO::Compat;
+    use mro 'c3';
     use Sub::Name 'subname';
 
     sub execute {
@@ -49,6 +50,11 @@ Catalyst::Action::DBIC::Transaction - Encloses actions into transactions
 
 =head1 DESCRIPTION
 
+THIS MODULE SHOULD BE CONSIDERED DEPRECATED. What is currently
+understood as a better practice is to enclose the code requiring a
+transaction into a proper model class. The point is that business
+logic should not be in the controller.
+
 This module enables the use of automatic transaction support into
 Catalyst Actions, it will associate a given action with the
 appropriate action class and save the DBIC::Schema model class name
