@@ -4,7 +4,7 @@ use base 'Catalyst::Controller::DBIC::Transaction';
 use strict;
 use warnings;
 
-sub bar :Local :DBICTransaction('MyTestSchemaReplacer') {
+sub bar :Local :DBICTransaction('DB') {
     my ($self, $c) = @_;
 
     ::ok('Inside the method');
